@@ -1,6 +1,19 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
+"""
+A Property can have between one and four values, each of which can also contain
+it's own graph handles.
+
+:value: The float value of the PropertyValue.
+:left_type: The type of the left graph handle.
+:left_x: The x-value of the left graph handle.
+:left_y: The y-value of the left graph handle.
+:right_type: The type of the right graph handle.
+:right_x: The x-value of the right graph handle.
+:right_y: The y-value of the right graph handle.
+"""
+
 """
 Apache2 License Notice
 Copyright 2018 Alex Barry
@@ -16,9 +29,6 @@ limitations under the License.
 """
 
 class AeselPropertyValue(object):
-    """
-    Data Model for Renderable Object.
-    """
     def __init__(self):
         self.value = None
         self.left_type = None
